@@ -142,6 +142,16 @@ class Metric(object):
     def __repr__(self):
         return ('<Metric: name=%s ...>' % (self.name)).encode('utf-8')
 
+class DataPoint(object):
+    def __init__(self, name, driver, average, numPoints):
+        self.name = name
+        self.driver = driver
+        self.average = average
+        self.numPoints = numPoints
+
+    def __repr__(self):
+        return ('<DataPoint: timestamp=%s ...>' % (self.name)).encode('utf-8')
+
 
 class NotificationType(object):
     def __init__(self, id, fields):
@@ -264,9 +274,10 @@ class Agent(object):
 
 
 class AgentConnection(object):
-    def __init__(self, id, endpoint, agent_id,
+    def __init__(self, id, guid, endpoint, agent_id,
                 bundle_version, process_version, agent_ip):
         self.id = id
+        self.guid = guid
         self.endpoint = endpoint
         self.agent_id = agent_id
         self.bundle_version = bundle_version
@@ -277,8 +288,8 @@ class AgentConnection(object):
         return self.__repr__()
 
     def __repr__(self):
-        return ('<AgentConnection: id=%s, agent_id=%s>' %
-            (self.id, self.agent_id)).encode('utf-8')
+        return ('<AgentConnection: id=%s, agent_id=%s, guid=%s>' %
+            (self.id, self.agent_id, self.guid)).encode('utf-8')
 
 
 class MonitoringDriver(object):
@@ -331,6 +342,10 @@ class MonitoringDriver(object):
         raise NotImplementedError(
             'list_metrics not implemented for this driver')
 
+    def fetch_data_point(self):
+        raise NotImplementedError(
+            'fetch_data_point not implemented for this driver')
+
     def list_monitoring_zones(self):
         raise NotImplementedError(
             'list_monitoring_zones not implemented for this driver')
