@@ -34,7 +34,7 @@ from rackspace_monitoring.base import (MonitoringDriver, Entity,
                                       Notification, CheckType, Alarm, Check,
                                       NotificationType, AlarmChangelog,
                                       LatestAlarmState, Agent, AgentToken,
-                                      AgentConnection, Metric)
+                                      AgentConnection, Metric, DataPoint)
 
 from libcloud.common.rackspace import AUTH_URL_US
 from libcloud.common.openstack import OpenStackBaseConnection
@@ -257,7 +257,7 @@ class RackspaceMonitoringDriver(MonitoringDriver):
 
         return rv
 
-    def _create(self, url, data, coerce):
+    def _create(self, url, data, coerce, handler=None):
         params = {}
 
         for k in data.keys():
@@ -278,7 +278,9 @@ class RackspaceMonitoringDriver(MonitoringDriver):
                                        method='POST',
                                        params=params,
                                        data=data)
-        if resp.status == httplib.CREATED:
+        if handler is not None:
+            return handler(resp)
+        elif resp.status == httplib.CREATED:
             location = resp.headers.get('location')
             if not location:
                 raise LibcloudError('Missing location header')
@@ -353,12 +355,24 @@ class RackspaceMonitoringDriver(MonitoringDriver):
     def _to_metrics(self, obj, value_dict=None):
         return Metric(name=obj['name'], driver=self)
 
+    def _to_datapoints(self, obj, value_dict=None):
+        return DataPoint(name=obj['timestamp'], driver=self,
+                     average=obj['average'], numPoints=obj['numPoints'])
+
     def list_metrics(self, entity_id, check_id, ex_next_marker=None):
         value_dict = {'url': '/entities/%s/checks/%s/metrics' %
                              (entity_id, check_id),
                         'list_item_mapper': self._to_metrics}
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
+    def fetch_data_point(self, entity_id, check_id, metric_name, from_timestamp, to_timestamp, points=1):
+        value_dict = {'url': '/entities/%s/checks/%s/metrics/%s/plot' %
+                             (entity_id, check_id, metric_name),
+                      'params': {'from': from_timestamp, 'to': to_timestamp, 'points': points},
+                      'list_item_mapper': self._to_datapoints}
+        return LazyList(get_more=self._get_more, value_dict=value_dict)
+
+
     def _to_monitoring_zone(self, obj, value_dict=None):
         return MonitoringZone(id=obj['id'], label=obj['label'],
                               country_code=obj['country_code'],
@@ -398,11 +412,15 @@ class RackspaceMonitoringDriver(MonitoringDriver):
 
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
-    def list_alarm_changelog(self, ex_next_marker=None, reverse=False):
+    def list_alarm_changelog(self, ex_next_marker=None, entity=None,
+            reverse=False):
         value_dict = {'url': '/changelogs/alarms',
                       'start_marker': ex_next_marker,
                       'params': {},
                       'list_item_mapper': self._to_alarm_changelog}
+        if entity is not None:
+            value_dict['entity_id'] = entity.id
+            value_dict['url'] += '?entityId=%s' % entity.id
         if reverse:
             value_dict['params']['reverse'] = reverse
 
@@ -732,13 +750,27 @@ class RackspaceMonitoringDriver(MonitoringDriver):
         return AgentToken(id=agent_token['id'], label=agent_token['label'],
                           token=agent_token['token'])
 
+
+    def _get_installer_headers(self, resp):
+        return {'shell_url': resp.headers.get('x-shell-installer-location'),
+                'json_url': resp.headers.get('location')}
+
+    def create_agent_installer(self, entity_id, **kwargs):
+        data = {'entity_id': entity_id,
+                'who': kwargs.get('who'),
+                'why': kwargs.get('why')}
+
+        return self._create('/agent_installers', data=data,
+                          coerce=None, handler=self._get_installer_headers)
+
+
     # Agent
 
     def _to_agents(self, agent, value_dict):
         return Agent(id=agent['id'], last_connected=agent['last_connected'])
 
     def _to_agent_connection(self, conn, value_dict):
-        return AgentConnection(id=conn['id'], endpoint=conn['endpoint'],
+        return AgentConnection(id=conn['id'], guid=conn['guid'], endpoint=conn['endpoint'],
             agent_id=conn['agent_id'], bundle_version=conn['bundle_version'],
             process_version=conn['process_version'], agent_ip=conn['agent_ip'])
 
